@@ -18,7 +18,6 @@
 from typing import Any, Callable, Dict, Optional
 
 from airflow.exceptions import AirflowException
-from airflow.operators.python_operator import PythonOperator
 from airflow.providers.http.hooks.http import HttpHook
 from airflow.sensors.base_sensor_operator import BaseSensorOperator
 from airflow.utils.decorators import apply_defaults
@@ -30,7 +29,10 @@ class HttpSensor(BaseSensorOperator):
     404 Not Found or `response_check` returning False.
 
     HTTP Error codes other than 404 (like 403) or Connection Refused Error
-    would fail the sensor itself directly (no more poking).
+    would raise an exception and fail the sensor itself directly (no more poking).
+    To avoid failing the task for other codes than 404, the argument ``extra_option``
+    can be passed with the value ``{'check_response': False}``. It will make the ``response_check``
+    be execute for any http status code.
 
     The response check can access the template context to the operator:
 
@@ -59,7 +61,9 @@ class HttpSensor(BaseSensorOperator):
     :param headers: The HTTP headers to be added to the GET request
     :type headers: a dictionary of string key/value pairs
     :param response_check: A check against the 'requests' response object.
-        Returns True for 'pass' and False otherwise.
+        The callable takes the response object as the first positional argument
+        and optionally any number of keyword arguments available in the context dictionary.
+        It should return True for 'pass' and False otherwise.
     :type response_check: A lambda or defined function.
     :param extra_options: Extra options for the 'requests' library, see the
         'requests' documentation (options to modify timeout, ssl, etc.)
@@ -67,7 +71,7 @@ class HttpSensor(BaseSensorOperator):
         depends on the option that's being modified.
     """
 
-    template_fields = ('endpoint', 'request_params')
+    template_fields = ('endpoint', 'request_params', 'headers')
 
     @apply_defaults
     def __init__(
@@ -78,7 +82,7 @@ class HttpSensor(BaseSensorOperator):
         method: str = 'GET',
         request_params: Optional[Dict[str, Any]] = None,
         headers: Optional[Dict[str, Any]] = None,
-        response_check: Optional[Callable[..., Any]] = None,
+        response_check: Optional[Callable[..., bool]] = None,
         extra_options: Optional[Dict[str, Any]] = None,
         **kwargs: Any,
     ) -> None:
@@ -93,6 +97,8 @@ class HttpSensor(BaseSensorOperator):
         self.hook = HttpHook(method=method, http_conn_id=http_conn_id)
 
     def poke(self, context: Dict[Any, Any]) -> bool:
+        from airflow.utils.operator_helpers import make_kwargs_callable
+
         self.log.info('Poking: %s', self.endpoint)
         try:
             response = self.hook.run(
@@ -102,8 +108,8 @@ class HttpSensor(BaseSensorOperator):
                 extra_options=self.extra_options,
             )
             if self.response_check:
-                op_kwargs = PythonOperator.determine_op_kwargs(self.response_check, context)
-                return self.response_check(response, **op_kwargs)
+                kwargs_callable = make_kwargs_callable(self.response_check)
+                return kwargs_callable(response, **context)
 
         except AirflowException as exc:
             if str(exc).startswith("404"):
